API docs for “spamfighter.core.commands.test.test_dispatcher.CommandDispatchTestCase”

# Class s.c.c.t.t.CommandDispatchTestCase(unittest.TestCase):

Part of spamfighter.core.commands.test.test_dispatcher View Source View In Hierarchy

Тестируем диспетчеризацию комманд.

Method | testDispatchAbsent | Undocumented
Method | testDispatchOK | Undocumented
Method | testDoubleInstall | Undocumented

def testDispatchAbsent(self): (source)
Undocumented
def testDispatchOK(self): (source)
Undocumented
def testDoubleInstall(self): (source)
Undocumented